# pydiscotools

pydiscotools is a set of tools to support Disco

| OS      | Tested             |
| ------- | ------------------ |
| Windows | :heavy_check_mark: |
| MacOs   | :x:                |
| Linux   | :x:                |
